/*
 * Copyright (c) 2016 ARM Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __MPS2_BOARD_BUTTONS_H__
#define __MPS2_BOARD_BUTTONS_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>

enum mps2_button_t {
  MPS2_FPGAIO_BTN,
  MPS2_SHIELD_BTN,
  MPS2_SCC_SW
};

enum mps2_btn_name_t {
  MPS2_FPGAIO_USERB0,
  MPS2_FPGAIO_USERB1,
  MPS2_SHIELD_USERB0,
  MPS2_SHIELD_USERB1,
  MPS2_SCC_SW1,
  MPS2_SCC_SW2,
  MPS2_SCC_SW3,
  MPS2_SCC_SW4,
  MPS2_SCC_SW5,
  MPS2_SCC_SW6,
  MPS2_SCC_SW7,
  MPS2_SCC_SW8
};

/**
 * \brief Gets number of available FPGA buttons.
 *
 * \param[in] btn_type  FPGA buttons type (\ref mps2_button_t).
 *
 * \return Number of available buttons.
 */
uint32_t mps2_get_nbr_btns(enum mps2_button_t btn_type);

/**
 * \brief Gets all FPGA buttons state.
 *
 * \param[in] btn_type  FPGA buttons type (\ref mps2_button_t).
 *
 * \returns buttons state.
*/
uint32_t mps2_get_all_btns_state(enum mps2_button_t btn_type);

/**
 * \brief Gets FPGA button state.
 *
 * \param[in] btn_id  FPGA button name (\ref mps2_btn_name_t).
 *
 * \returns button state.
*/
uint32_t mps2_get_btn_state(enum mps2_btn_name_t btn_id);

#ifdef __cplusplus
}
#endif
#endif /* __MPS2_BOARD_BUTTONS_H__ */
