/*
 * Copyright (c) 2017 ARM Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdint.h>
#include <stdbool.h>

#include "cmsis.h"
#include "mps2_devices.h"
#include "s_ns_shared.h"

#if defined (__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
__asm(".global __ARM_use_no_argv\n");
#endif

#define ALL_SCC_LEDS_OFF  0x0
#define ALL_SCC_LEDS_ON   0xFFFFFFFF

#define BLINK_TIME        500U  /* ms */
#define SLEEP_TIME        500U  /* ms */

int main(void)
{
    uint32_t btns_state;
    bool is_blink_active = true;

    mps2_set_leds(MPS2_SCC_LED, ALL_SCC_LEDS_ON);

    while(1) {
        /* Secure code call */
        btns_state = get_btns_state();

        if(btns_state & BT0_MASK) {
            /* Blink SCC LEDs */
            is_blink_active = true;
        } else if (btns_state & BT1_MASK) {
            /* Stop SCC LEDs blink */
            is_blink_active = false;
        }

        if(is_blink_active) { /* Secure code call */
            mps2_set_leds(MPS2_SCC_LED, ALL_SCC_LEDS_OFF);
            sleep_ms(BLINK_TIME); /* Secure code call */
            mps2_set_leds(MPS2_SCC_LED, ALL_SCC_LEDS_ON);
            sleep_ms(BLINK_TIME); /* Secure code call */
        } else {
            sleep_ms(SLEEP_TIME); /* Secure code call */
        }
    }
}
